# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['doveseed']

package_data = \
{'': ['*']}

install_requires = \
['Werkzeug>=2.2.2,<3.0.0',
 'flask>=2.2.2,<3.0.0',
 'flask_cors>=3.0,<4.0',
 'jinja2>=3.1.2,<4.0.0',
 'tinydb>=4.7.0,<5.0.0',
 'typing_extensions>=4.3.0,<5.0.0']

setup_kwargs = {
    'name': 'doveseed',
    'version': '1.1.0a4',
    'description': 'Doveseed is a backend service for email subscriptions to RSS feeds.',
    'long_description': '.. image:: https://github.com/jgosmann/doveseed/actions/workflows/ci.yml/badge.svg\n  :target: https://github.com/jgosmann/doveseed/actions/workflows/ci.yml\n  :alt: CI and release pipeline\n.. image:: https://codecov.io/gh/jgosmann/doveseed/branch/master/graph/badge.svg\n  :target: https://codecov.io/gh/jgosmann/doveseed\n  :alt: Codecov coverage\n.. image:: https://img.shields.io/pypi/v/doveseed\n  :target: https://pypi.org/project/doveseed/\n  :alt: PyPI\n.. image:: https://img.shields.io/pypi/pyversions/doveseed\n  :target: https://pypi.org/project/doveseed/\n  :alt: PyPI - Python Version\n.. image:: https://img.shields.io/pypi/l/doveseed\n  :target: https://pypi.org/project/doveseed/\n  :alt: PyPI - License\n\n\nDoveseed\n========\n\nDoveseed is a backend service for email subscriptions to RSS feeds.\n\n\nSetup\n-----\n\nConfiguration\n^^^^^^^^^^^^^\n\nDoveseed requires a configuration file in JSON format. Take a look at\n``config.sample.json``. The format is as follows:\n\n* ``cors``: Maybe omitted to disable CORS headers. If given, will be passed to\n  ``CORS`` constructor of `flask-cors <https://flask-cors.readthedocs.io/en/latest/>`_.\n* ``db``: JSON file in which Doveseed persists its data.\n* ``rss``: URL to the RSS feed for which new notifications are to be send.\n* ``smtp``\n\n  * ``host``: SMTP host used to send notification emails.\n  * ``user``: SMTP logon user name.\n  * ``password``: SMTP logon password.\n  * ``ssl_mode``: Activate/deactivate SSL/TLS, valid values `"no-ssl"`, `"start-tls"`, `"tls"` (default `"start-tls"`).\n  * ``check_hostname``: Whether to verify the hostname when using TLS (default `true`).\n\n* ``template_vars``: Defines template variables to replace in the email templates.\n\n  * ``display_name``: Name for the website to use in emails.\n  * ``host``: Hostname of the website.\n  * ``sender``: Email address that is sending the notifications.\n  * ``confirm_url_format``: Template for the URL that is used for confirmation\n    links. The following values will be replaced in it:\n\n    * ``{host}`` with the specified host,\n    * ``{email}`` with the email address to confirm,\n    * ``{token}`` with the confirmation token,\n    * ``{{`` and ``}}`` with ``{`` and ``}``.\n\n* ``email_templates``: Path to the templates for the emails.\n* ``confirm_timeout_minutes``: Timeout in minutes during which a subscription needs to be confirmed.\n\n**Ensure that the configuration files have appropriate permissions, i.e. only\nreadable by you and Doveseed.**\n\nBy default the configuration filename is assumed to be ``config.json``.\n\n\nEmail templates\n^^^^^^^^^^^^^^^\n\nTemplates for the emails sent out are written in\n`Jinja <https://jinja.palletsprojects.com/en/2.11.x/>`_.\nLook in ``templates/example`` for example email templates.\nThere is a template for each type of email being sent:\n\n* ``new-post.*``: for notifications about new posts,\n* ``subscribe.*``: for requesting confirmation to a new subscription,\n* and ``unsubscribe.*``: for requesting confirmation to a cancellation of a subscription.\n\nEach of these templates consists out of three files:\n\n* ``*.subject.txt``: for the subject line of the email,\n* ``*.txt``: for the plain text version of the email,\n* and ``*.html``: for the HTML version of the email.\n\n\n\nREST service\n^^^^^^^^^^^^\n\nThe REST service runs as a Python WSGI app. Any WSGI app server could be used.\n\nPassenger\n~~~~~~~~~\n\nSample ``passenger_wsgi.py`` file::\n\n    import logging\n    logging.basicConfig(filename="/path/to/log", level=logging.WARN)\n\n    from doveseed.app import create_app\n    application = create_app()\n\n\nCORS\n~~~~\n\nTo set appropriate CORS headers use the\n`flask-cors <https://flask-cors.readthedocs.io/en/latest/>`_ package.\nActivate it by adding the following lines to the file where you instantiate\nthe app, for example your ``passenger_wsgi.py`` file::\n\n    from flask_cors import CORS\n    CORS(application, origins=["https://my-domain.tld"])\n\n\nReCaptcha\n~~~~~~~~~\n\nTo activate `ReCaptcha (v2) <https://www.google.com/recaptcha/>`_ verification of\nrequests, add the follwing lines to the file where you instantiate the app,\nfor example your ``passenger_wsgi.py`` file::\n\n    from doveseed.recaptcha import ReCaptchaMiddleware\n    application.wsgi_app = ReCaptchaMiddleware(\n        application.wsgi_app, \'^/(un)?subscribe/.*\', \'recaptcha.json\')\n\nAlso, create the ``recaptcha.json`` with the required ReCaptcha configuration::\n\n* ``hostnames``: List of hostnames to accept ReCaptchas from.\n* ``secret``: The shared key between your site and reCAPTCHA.\n\n\n**Ensure that the configuration files have appropriate permissions, i.e. only\nreadable by you and Doveseed.**\n\n\nDatabase cleanup\n^^^^^^^^^^^^^^^^\n\nExpired pending subscription can be cleaned from the database with::\n\n    python -m doveseed.cli clean <path to config file>\n\nIdeally, this command is run once per day as a cron job.\n\n\nChecking for new posts\n^^^^^^^^^^^^^^^^^^^^^^\n\nTo check for new post and send notification emails run::\n\n    python -m doveseed.cli notify <path to config file>\n\nThis can either run in a regular interval as a cron job or it can be triggered\nin some way after new posts have been published.\n\n**Run this command once to initialize the database before going live because\ninitially all items in the RSS feed will be considered to be old.** (This\nprevents sending a notification email for all already existing items in the\nfeed.)\n\n\nREST interface\n--------------\n\nSubscribe\n^^^^^^^^^\n\nTo subscribe with an email address::\n\n    POST /subscribe/<url encoded email>\n    Content-Type: application/json\n\n    { captcha: "ReCaptcha returned from Google API" }\n\nThis will return a ``201 NO CONTENT`` and send out the email requesting\nconfirmation.\n\nUnsubscribe\n^^^^^^^^^^^\n\nTo unsubscribe an email address::\n\n    POST /unsubscribe/<url encoded email>\n    Content-Type: application/json\n\n    { captcha: "ReCaptcha returned from Google API" }\n\nThis will return a ``201 NO CONTENT`` and send out the email requesting\nconfirmation if the email is subscribed.\n\nConfirm\n^^^^^^^\n\nTo confirm a request to subscribe or unsubscribe::\n\n    POST /confirm/<url encoded email>\n    Content-Type: application/json\n    Authorization: Bearer <token from confirmation reuest email>\n\nThis will return a ``201 NO CONTENT`` on success,\nand ``401 UNAUTHORIZED`` if the token or email is invalid.\n',
    'author': 'Jan Gosmann',
    'author_email': 'jan@hyper-world.de',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/jgosmann/doveseed/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
